#
# spec file for package python-panflute
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-panflute
Version:        2.3.1
Release:        1.2
Summary:        Pandoc filters package for Python
License:        BSD-3-Clause
URL:            https://github.com/sergiocorreia/panflute
Source:         https://files.pythonhosted.org/packages/source/p/panflute/panflute-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PyYAML
Requires:       python-click
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module PyYAML}
BuildRequires:  %{python_module click}
BuildRequires:  %{python_module pytest-cov}
BuildRequires:  %{python_module pytest}
%if %{with python2}
BuildRequires:  python-configparser
BuildRequires:  python-shutilwhich
%endif
# /SECTION
%python_subpackages

%description
Panflute is a Python package for writing Pandoc filters.

%prep
%setup -q -n panflute-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/panfl
%python_clone -a %{buildroot}%{_bindir}/panflute
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative panfl
%python_install_alternative panflute

%postun
%python_uninstall_alternative panfl
%python_uninstall_alternative panflute

%files %{python_files}
%doc README.md
%license LICENSE
%python_alternative %{_bindir}/panflute
%python_alternative %{_bindir}/panfl
%{python_sitelib}/panflute
%{python_sitelib}/panflute-%{version}.dist-info

%changelog
* Thu Mar 21 2024 Dirk Müller <dmueller@suse.com>
- update to 2.3.1:
  * Document that pandoc 3.1.* is supported
  * Document older pandoc 2.19 support
  * Make MetaMap/List completely pythonic
  * Figure, Table: fix to_json() crash if caption is None
* Fri Sep  1 2023 Steve Kowalik <steven.kowalik@suse.com>
- Stop using greedy globs in %%files.
- Switch to pyproject macros.
- Drop unneeded {Build,}Requires on future.
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- update to 2.3.0:
  * Update Pandoc API from 1.22 to 1.23 (Pandoc 3.0):
  * Add `Figure` block object
  * Remove `Null` block object (scheduled for removed)
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 2.2.3
  * Added equality operator to element objects (Doc, Block, Inline, Str, etc.)
    Misc. bugfixes
- Update to version 2.2.1
  * Minor improvement to stringify()
  * Bugfixes detected by flake8
- Update to version 2.2.0
  * The run_filters() function, as well as .walk() method now support as optional argument a stop_if function.
    If this argument is used and not none, then .walk() will not walk through an element's children if stop_if(element) is True.
  This has two uses:
  We can speed up filters by avoiding going too deep into the document's tree. For instance:
  def stop_if(elem):
    return isinstance(elem, pf.Inline)
  Will stop walking the tree once it reaches an inline element
  * Some filters become easier to write, because we can just act on a main element such as Table and then by hand call .walk() to each table component
    This also simplifies possible stringify() improvements, as discussed in #218 and illustrated in c8b4365 for DefinitionList elements
    Other minor changes:
    Simplified element.walk() code and added .walk() methods to ListContainer and DictContainer
    Minor code cleanup to reduce pycodestyle warnings
- Update to version 2.1.3
  * Update documentation and dependencies:
  Add support and test against Python 3.10 and Pandoc 2.16
  * Improve test matrix suite
  Test and document lists of elements as return values of filters (the items on the list will be inserted at the same level as the item being replaced)
- Update to version 2.1.1
  * Same as 2.1.0 but fixed a dependency (wheels) required to publish to pypi
- Update to version 2.1.0
  * autofilter.py: add pandoc 2.12+ support to get_filter_dirs
  * add pandoc_path argument to run_pandoc(): run_pandoc(text='', args=None, pandoc_path=which('pandoc')
  * fix a few docstrings
- Update to version 2.0.5
  * Fix #166 ("Regression: panflute.elements.builtin2meta no longer supports subclasses of builtins")
  * Improve testing ( #170, #169, #164)
* Wed May 20 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Mon Apr 20 2020 Tomáš Chvátal <tchvatal@suse.com>
- Fix build without python2
* Thu Mar 12 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to version 1.12.5
  * tweak error messages of panflute.dump
  * allow slice assignment to element items (via ListContainer)
  * Tables should now work well without a header or without a body.
  * stringify() now adds quotes around the contents of a Quoted() element.
* Tue Nov 19 2019 Todd R <toddrme2178@gmail.com>
- shutilwhich isn't needed for python3 and prevents other python
  packages using this one.
* Thu May  2 2019 Todd R <toddrme2178@gmail.com>
- Initial version
